@@ -1,4 +1,4 @@
-/* Copyright 2004,2007,2008,2010 ENSEIRB, INRIA & CNRS
+/* Copyright 2004,2007,2008,2010,2011,2014 IPB, Universite de Bordeaux, INRIA & CNRS
 **
 ** This file is part of the Scotch software package for static mapping,
 ** graph partitioning and sparse matrix ordering.
@@ -34,6 +34,7 @@
 /**   NAME       : arch_vhcub.c                            **/
 /**                                                        **/
 /**   AUTHOR     : Francois PELLEGRINI                     **/
+/**                Sebastien FOURESTIER (v6.0)             **/
 /**                                                        **/
 /**   FUNCTION   : This module handles the variable-sized  **/
 /**                hypercube target architecture.          **/
@@ -44,6 +45,8 @@
 /**                                 to     04 nov 2003     **/
 /**                # Version 5.1  : from : 21 jan 2008     **/
 /**                                 to     27 feb 2008     **/
+/**                # Version 6.0  : from : 14 fev 2011     **/
+/**                                 to     26 aug 2014     **/
 /**                                                        **/
 /************************************************************/
 
@@ -95,11 +98,13 @@ const ArchDomNum            domnum)
   Anum                termnum;
   Anum                termlvl;
 
-  if (domnum != ARCHDOMNOTTERM) {                 /* If valid label   */
-    domptr->termnum = domnum;                     /* Set the domain   */
-    for (termnum = domnum, termlvl = 0; termnum > 1; /* Compute level */
-         termnum >>= 1, termlvl ++) ;
-    domptr->termlvl = termnum;                    /* Set level */
+  if (domnum != ARCHDOMNOTTERM) {                 /* If valid label     */
+    if (domnum == 0)                              /* Not a legal domain */
+      return (2);
+
+    domptr->termnum = domnum;                     /* Set the domain */
+    for (termnum = domnum, termlvl = 0; termnum > 1; termnum >>= 1, termlvl ++) ; /* Compute level */
+    domptr->termlvl = termlvl;                    /* Set level */
 
     return (0);
   }
@@ -144,7 +149,7 @@ const ArchVhcubDom * const  dom1ptr)
     distval = (dom1ptr->termlvl - dom0ptr->termlvl) >> 1; /* One half of unknown bits */
   }
 
-  for (dom0num ^= dom1num; dom0num != 0;          /* Compute number of bit differences */
+  for (dom0num ^= dom1num; dom0num != 0;          /* Compute Hamming distance */
        distval += (dom0num & 1), dom0num >>= 1) ;
 
   return (distval);
@@ -183,15 +188,17 @@ const ArchVhcub * const       archptr,
 ArchVhcubDom * restrict const domptr,
 FILE * const                  stream)
 {
-  if ((intLoad (stream, &domptr->termlvl) != 1)    ||
-      (intLoad (stream, &domptr->termnum) != 1)    ||
-      (domptr->termlvl < 0)                        ||
-      (domptr->termnum <  (1 <<  domptr->termlvl)) ||
-      (domptr->termnum >= (1 << (domptr->termlvl + 1)))) {
+  Anum                termnum;
+  Anum                termlvl;
+
+  if (intLoad (stream, &domptr->termnum) != 1) {
     errorPrint ("archVhcubDomLoad: bad input");
     return     (1);
   }
 
+  for (termnum = domptr->termnum, termlvl = 0; termnum > 1; termnum >>= 1, termlvl ++) ; /* Compute level */
+  domptr->termlvl = termlvl;
+
   return (0);
 }
 
@@ -208,8 +215,7 @@ const ArchVhcub * const     archptr,
 const ArchVhcubDom * const  domptr,
 FILE * const                stream)
 {
-  if (fprintf (stream, ANUMSTRING " " ANUMSTRING " ",
-               (Anum) domptr->termlvl,
+  if (fprintf (stream, ANUMSTRING " ",
                (Anum) domptr->termnum) == EOF) {
     errorPrint ("archVhcubDomSave: bad output");
     return     (1);
@@ -240,6 +246,27 @@ ArchVhcubDom * restrict const dom1ptr)
   return ((dom1ptr->termnum < domptr->termnum) ? 2 : 0); /* Return error on overflow */
 }
 
+/* This function checks if dom1 is
+** included in dom0.
+** It returns:
+** - 0  : if dom1 is not included in dom0.
+** - 1  : if dom1 is included in dom0.
+** - 2  : on error.
+*/
+
+int
+archVhcubDomIncl (
+const ArchVhcub * const     archptr,
+const ArchVhcubDom * const  dom0ptr,
+const ArchVhcubDom * const  dom1ptr)
+{
+  if ((dom1ptr->termlvl >= dom0ptr->termlvl) &&
+      ((dom1ptr->termnum >> (dom1ptr->termlvl - dom0ptr->termlvl)) == dom0ptr->termnum))
+    return (1);
+
+  return (0);
+}
+
 /* This function creates the MPI_Datatype for
 ** variable-sized hypercube domains.
 ** It returns:
