@@ -1,4 +1,4 @@
-/* Copyright 2007,2008,2010,2011 ENSEIRB, INRIA & CNRS
+/* Copyright 2007,2008,2010,2011,2014 IPB, Universite de Bordeaux, INRIA & CNRS
 **
 ** This file is part of the Scotch software package for static mapping,
 ** graph partitioning and sparse matrix ordering.
@@ -45,6 +45,8 @@
 /**                                                        **/
 /**   DATES      : # Version 5.1  : from : 11 nov 2007     **/
 /**                                 to   : 14 apr 2011     **/
+/**                # Version 6.0  : from : 11 sep 2011     **/
+/**                                 to   : 31 aug 2014     **/
 /**                                                        **/
 /**   NOTES      : # Since only edges from local vertices  **/
 /**                  to local anchors are created in       **/
@@ -197,9 +199,10 @@ const BdgraphBipartBdParam * const  paraptr)      /*+ Method parameters +*/
   bndgrafdat.commglbgainextn  = orggrafptr->commglbgainextn;
   bndgrafdat.commglbloadextn0 = orggrafptr->commglbloadextn0;
   bndgrafdat.commglbgainextn0 = orggrafptr->commglbgainextn0;
-  bndgrafdat.domdist          = orggrafptr->domdist;
-  bndgrafdat.domwght[0]       = orggrafptr->domwght[0];
-  bndgrafdat.domwght[1]       = orggrafptr->domwght[1];
+  bndgrafdat.bbalglbval       = orggrafptr->bbalglbval;
+  bndgrafdat.domndist         = orggrafptr->domndist;
+  bndgrafdat.domnwght[0]      = orggrafptr->domnwght[0];
+  bndgrafdat.domnwght[1]      = orggrafptr->domnwght[1];
   bndgrafdat.levlnum          = orggrafptr->levlnum;
 
   if (bndgrafdat.veexloctax != NULL) {
@@ -433,8 +436,9 @@ loop_exit :
   }
   orggrafptr->fronlocnbr      = orgfronlocnum;
   orggrafptr->fronglbnbr      = reduglbtab[3];
-  orggrafptr->commglbload     = (reduglbtab[0] / 2) * orggrafptr->domdist + reduglbtab[1];
+  orggrafptr->commglbload     = (reduglbtab[0] / 2) * orggrafptr->domndist + reduglbtab[1];
   orggrafptr->commglbgainextn = reduglbtab[2];
+  orggrafptr->bbalglbval      = (double) ((orggrafptr->compglbload0dlt < 0) ? (- orggrafptr->compglbload0dlt) : orggrafptr->compglbload0dlt) / (double) orggrafptr->compglbload0avg;
 
 #ifdef SCOTCH_DEBUG_BDGRAPH2
   if (bdgraphCheck (orggrafptr) != 0) {
