@@ -1,4 +1,4 @@
-/* Copyright 2007-2009 ENSEIRB, INRIA & CNRS
+/* Copyright 2007-2009,2014 IPB, Universite de Bordeaux, INRIA & CNRS
 **
 ** This file is part of the Scotch software package for static mapping,
 ** graph partitioning and sparse matrix ordering.
@@ -42,6 +42,8 @@
 /**                                                        **/
 /**   DATES      : # Version 5.1  : from : 30 oct 2007     **/
 /**                                 to   : 29 oct 2009     **/
+/**                # Version 6.0  : from : 28 sep 2014     **/
+/**                                 to     28 sep 2014     **/
 /**                                                        **/
 /************************************************************/
 
@@ -52,14 +54,14 @@
 /*+ This structure holds the method parameters. +*/
 
 typedef struct BdgraphBipartMlParam_ {
-  INT                       passnbr;              /*+ Number of coarsening passes to go           +*/
-  INT                       coarnbr;              /*+ Minimum number of vertices                  +*/
-  INT                       dupmax;               /*+ Maximum number of vertices to do fold-dup   +*/
-  INT                       duplvlmax;            /*+ Maximum level for allowing fold-dup         +*/
-  double                    coarrat;              /*+ Coarsening ratio                            +*/
-  Strat *                   stratlow;             /*+ Strategy at lowest level                    +*/
-  Strat *                   stratasc;             /*+ Strategy at ascending levels                +*/
-  Strat *                   stratseq;             /*+ Strategy when running on a single processor +*/
+  INT                       passnbr;              /*+ Number of coarsening passes to go                      +*/
+  INT                       foldmax;              /*+ Maximum number of vertices per processor to do folding +*/
+  int                       foldval;              /*+ Type of folding                                        +*/
+  INT                       coarnbr;              /*+ Minimum number of vertices                             +*/
+  double                    coarrat;              /*+ Coarsening ratio                                       +*/
+  Strat *                   stratlow;             /*+ Strategy at lowest level                               +*/
+  Strat *                   stratasc;             /*+ Strategy at ascending levels                           +*/
+  Strat *                   stratseq;             /*+ Strategy when running on a single processor            +*/
 } BdgraphBipartMlParam;
 
 typedef struct BdgraphBipartMlSort_ {
