@@ -1,4 +1,4 @@
-/* Copyright 2004,2007,2011 ENSEIRB, INRIA & CNRS
+/* Copyright 2004,2007,2011,2012 IPB, Universite de Bordeaux, INRIA & CNRS
 **
 ** This file is part of the Scotch software package for static mapping,
 ** graph partitioning and sparse matrix ordering.
@@ -43,6 +43,8 @@
 /**                                 to     28 may 2007     **/
 /**                # Version 5.1  : from : 29 oct 2007     **/
 /**                                 to     28 mar 2011     **/
+/**                # Version 6.0  : from : 08 nov 2011     **/
+/**                                 to     20 nov 2012     **/
 /**                                                        **/
 /************************************************************/
 
@@ -56,7 +58,7 @@
 
 /*+ Sign masking operator. +*/
 
-#define BGRAPHBIPARTDFGNUMSGNMSK(i) ((Gnum) 0 - (((Gunum) (i)) >> (sizeof (Gnum) * 8 - 1)))
+#define BGRAPHBIPARTDFGNUMSGNMSK(i) (- (Gnum) (((Gunum) (i)) >> (sizeof (Gnum) * 8 - 1)))
 
 /*
 **  The type and structure definitions.
@@ -72,12 +74,45 @@ typedef enum BgraphBipartDfType_ {
 /*+ Method parameters. +*/
 
 typedef struct BgraphBipartDfParam_ {
-  INT                       passnbr;              /*+ Number of passes to do        +*/
-  double                    cdifval;              /*+ Coefficient of diffused load  +*/
-  double                    cremval;              /*+ Coefficient of remaining load +*/
-  BgraphBipartDfType        typeval;              /*+ Type of balance to reach      +*/
+  INT                       passnbr;              /*+ Number of passes to do   +*/
+  BgraphBipartDfType        typeval;              /*+ Type of balance to reach +*/
 } BgraphBipartDfParam;
 
+/*+ The loop routine parameter
+    structure. It contains the
+    thread-independent data.   +*/
+
+typedef struct BgraphBipartDfData_ {
+  ThreadGroupHeader         thrddat;
+  Bgraph *                  grafptr;              /*+ Graph to work on          +*/
+  float *                   difntax;              /*+ New diffusion value array +*/
+  float *                   difotax;              /*+ Old diffusion value array +*/
+  INT                       passnbr;              /*+ Number of passes          +*/
+  Gnum                      vanctab[2];           /*+ Anchor load arrays        +*/
+#ifdef BGRAPHBIPARTDFTHREAD
+  int                       abrtval;              /*+ Abort value               +*/
+#endif /* BGRAPHBIPARTDFTHREAD */
+} BgraphBipartDfData;
+
+/*+ The thread-specific data block. +*/
+
+typedef struct BgraphBipartDfThread_ {
+  ThreadHeader              thrddat;              /*+ Thread management data                       +*/
+  Gnum                      vertbas;              /*+ Minimum regular vertex index                 +*/
+  Gnum                      vertnnd;              /*+ After-last regular vertex index              +*/
+  Gnum                      fronnnd;              /*+ After-last frontier vertex index             +*/
+  Gnum                      compload1;            /*+ State return values to aggregate             +*/
+  Gnum                      compsize1;
+  Gnum                      commloadextn;
+  Gnum                      commloadintn;
+  Gnum                      commgainextn;
+  float                     vanctab[2];           /*+ Area for (reducing) contributions to anchors +*/
+#ifdef BGRAPHBIPARTDFTHREAD
+  Gnum                      veexsum;              /*+ Area for reducing sums of external gains     +*/
+  Gnum                      veexsum1;
+#endif /* BGRAPHBIPARTDFTHREAD */
+} BgraphBipartDfThread;
+
 /*
 **  The function prototypes.
 */
