@@ -1,4 +1,4 @@
-/* Copyright 2004,2007,2009,2011 ENSEIRB, INRIA & CNRS
+/* Copyright 2004,2007,2009,2011,2013,2014 IPB, Universite de Bordeaux, INRIA & CNRS
 **
 ** This file is part of the Scotch software package for static mapping,
 ** graph partitioning and sparse matrix ordering.
@@ -35,6 +35,7 @@
 /**                                                        **/
 /**   AUTHOR     : Francois PELLEGRINI                     **/
 /**                Luca SCARANO (v3.1)                     **/
+/**                Sebastien FOURESTIER (v6.0)             **/
 /**                                                        **/
 /**   FUNCTION   : This module computes a bipartition of   **/
 /**                a bipartition graph by multiple runs of **/
@@ -54,6 +55,8 @@
 /**                                 to     04 feb 2007     **/
 /**                # Version 5.1  : from : 21 nov 2007     **/
 /**                                 to     22 feb 2011     **/
+/**                # Version 6.0  : from : 23 fev 2011     **/
+/**                                 to     08 aug 2014     **/
 /**                                                        **/
 /************************************************************/
 
@@ -63,9 +66,12 @@
 
 #define BGRAPH_BIPART_GG
 
+#define SCOTCH_TABLE_GAIN
+
 #include "module.h"
 #include "common.h"
 #include "gain.h"
+#include "fibo.h"
 #include "graph.h"
 #include "arch.h"
 #include "bgraph.h"
@@ -84,6 +90,31 @@ static const Gnum           bgraphbipartggloadzero = 0;
 /*                           */
 /*****************************/
 
+#ifndef SCOTCH_TABLE_GAIN
+
+/* bgraphBipartFmCmpFunc(a,b) must return a negative
+** number if a is "better" than b. The smaller, the
+** better.
+*/
+
+static
+int
+bgraphBipartGgCmpFunc (
+const FiboNode * const      data0ptr,             /* TRICK: BgraphBipartFmLink is FIRST in BgraphBipartFmVertex */
+const FiboNode * const      data1ptr)
+{
+  const BgraphBipartGgVertex * const  node0ptr = (BgraphBipartGgVertex *) data0ptr;
+  const BgraphBipartGgVertex * const  node1ptr = (BgraphBipartGgVertex *) data1ptr;
+
+  if (node0ptr->commgain < node1ptr->commgain)
+    return (-1);
+  if (node0ptr->commgain > node1ptr->commgain)
+    return (1);
+  return (0);
+}
+ 
+#endif /* SCOTCH_TABLE_GAIN */
+
 /* This routine performs the bipartitioning.
 ** It returns:
 ** - 0 : if bipartitioning could be computed.
@@ -95,46 +126,53 @@ bgraphBipartGg (
 Bgraph * restrict const           grafptr,        /*+ Active graph      +*/
 const BgraphBipartGgParam * const paraptr)        /*+ Method parameters +*/
 {
-  GainTabl * restrict             tablptr;        /* Pointer to gain table                      */
-  BgraphBipartGgVertex * restrict vexxtax;        /* Extended vertex array                      */
-  BgraphBipartGgVertex *          vexxptr;        /* Pointer to current vertex to swap          */
-  const Gnum * restrict           veexptr;        /* Pointer to external gain of current vertex */
-  Gnum * restrict                 permtab;        /* Permutation table for finding new roots    */
-  Gnum                            permnum;        /* Current permutation index                  */
-  const Gnum * restrict           velobax;        /* Data for handling of optional arrays       */
-  Gnum                            velomsk;
-  const byte * restrict           veexbab;        /* Un-based array for external gains          */
-  int                             veexsiz;
-  const Gnum * restrict           edlobax;
-  Gnum                            edlomsk;
-  byte * restrict                 flagtax;
-  Gnum                            vertnum;
-  Gnum                            fronnum;
-  Gnum                            compsize1;
-  Gnum                            commgainextn;
-  unsigned int                    passnum;
-  Anum                            domdist2;       /* Two times domdist */
+  BgraphBipartGgTabl      tabldat;                /* Gain table                                   */
+  BgraphBipartGgVertex *  vexxtax;                /* Extended vertex array [norestrict]           */
+  BgraphBipartGgVertex *  vexxptr;                /* Pointer to current vertex to swap            */
+  const Gnum * restrict   veexptr;                /* Pointer to external gain of current vertex   */
+  Gnum * restrict         permtab;                /* Permutation table for finding new roots      */
+  Gnum                    permnum;                /* Current permutation index                    */
+  const Gnum * restrict   velobax;                /* Data for handling of optional arrays         */
+  Gnum                    velomsk;
+  const byte * restrict   veexbab;                /* Un-based array for external gains            */
+  int                     veexsiz;
+  const Gnum *            edlobax;                /* Pointer to array or dummy value [norestrict] */
+  Gnum                    edlomsk;
+  byte * restrict         flagtax;
+  Gnum                    vertnum;
+  Gnum                    fronnum;
+  Gnum                    compsize1;
+  Gnum                    commgainextn;
+  unsigned int            passnum;
+  Anum                    domndist;
+  Anum                    domndist2;              /* Two times domndist */
 
-  if (((tablptr = gainTablInit (GAIN_LINMAX, BGRAPHBIPARTGGGAINTABLSUBBITS)) == NULL) || /* Use logarithmic array only */
+  const Gnum * restrict const verttax = grafptr->s.verttax; /* Fast accesses */
+  const Gnum * restrict const vendtax = grafptr->s.vendtax;
+  const Gnum * restrict const edgetax = grafptr->s.edgetax;
+  const Gnum * const          edlotax = grafptr->s.edlotax; /* [norestrict] */
+  const Gnum * restrict const veextax = grafptr->veextax;
+
+  if ((bgraphBipartGgTablInit (&tabldat) != 0) ||
       ((vexxtax = (BgraphBipartGgVertex *) memAlloc (grafptr->s.vertnbr * sizeof (BgraphBipartGgVertex))) == NULL)) {
     errorPrint ("bgraphBipartGg: out of memory (1)");
-    if (tablptr != NULL)
-      gainTablExit (tablptr);
+    bgraphBipartGgTablExit (&tabldat);
     return (1);
   }
   vexxtax -= grafptr->s.baseval;                  /* Base access to vexxtax                */
   permtab  = NULL;                                /* Do not allocate permutation array yet */
 
-  domdist2 = 2 * grafptr->domdist;
+  domndist  = grafptr->domndist;
+  domndist2 = grafptr->domndist * 2;
 
-  if (grafptr->s.edlotax == NULL) {               /* If graph has no edge weights */
+  if (edlotax == NULL) {                          /* If graph has no edge weights */
     Gnum                vertnum;
 
     for (vertnum = grafptr->s.baseval; vertnum < grafptr->s.vertnnd; vertnum ++) {
       Gnum                commload;
 
-      commload = (grafptr->s.vendtax[vertnum] - grafptr->s.verttax[vertnum]) * grafptr->domdist;
-      vexxtax[vertnum].commgain0 = (grafptr->veextax == NULL) ? commload : commload + grafptr->veextax[vertnum];
+      commload = (vendtax[vertnum] - verttax[vertnum]) * domndist;
+      vexxtax[vertnum].commgain0 = (veextax == NULL) ? commload : commload + veextax[vertnum];
     }
 
     edlobax = &bgraphbipartggloadone;
@@ -147,16 +185,16 @@ const BgraphBipartGgParam * const paraptr)        /*+ Method parameters +*/
       Gnum                commload;
       Gnum                edgenum;
 
-      for (edgenum = grafptr->s.verttax[vertnum], commload = 0;
-           edgenum < grafptr->s.vendtax[vertnum]; edgenum ++)
-        commload += grafptr->s.edlotax[edgenum];
-      commload *= grafptr->domdist;
+      for (edgenum = verttax[vertnum], commload = 0;
+           edgenum < vendtax[vertnum]; edgenum ++)
+        commload += edlotax[edgenum];
+      commload *= domndist;
 
-      vexxtax[vertnum].commgain0 = (grafptr->veextax == NULL) ? commload : commload + grafptr->veextax[vertnum];
+      vexxtax[vertnum].commgain0 = (veextax == NULL) ? commload : commload + veextax[vertnum];
     }
 
-    edlobax = grafptr->s.edlotax;
-    edlomsk = ~((Gnum) 0);                        /* TRICK: will assume that ~0 is -1 */
+    edlobax = edlotax;
+    edlomsk = ~((Gnum) 0);                        /* TRICK: assume that ~0 is -1 */
   }
   if (grafptr->s.velotax == NULL) {               /* Set accesses to optional arrays             */
     velobax = &bgraphbipartggloadone;             /* In case vertices not weighted (least often) */
@@ -166,12 +204,12 @@ const BgraphBipartGgParam * const paraptr)        /*+ Method parameters +*/
     velobax = grafptr->s.velotax;
     velomsk = ~((Gnum) 0);
   }
-  if (grafptr->veextax == NULL) {
+  if (veextax == NULL) {
     veexbab = (byte *) &bgraphbipartggloadzero;
     veexsiz = 0;
   }
   else {
-    veexbab = (byte *) (grafptr->veextax + grafptr->s.baseval);
+    veexbab = (byte *) (veextax + grafptr->s.baseval);
     veexsiz = sizeof (Gnum);
   }
 
@@ -181,10 +219,10 @@ const BgraphBipartGgParam * const paraptr)        /*+ Method parameters +*/
     Gnum                compload0dlt;
 
     for (vertnum = grafptr->s.baseval; vertnum < grafptr->s.vertnnd; vertnum ++) { /* Reset extended vertex array */
-      vexxtax[vertnum].gainlink.next = BGRAPHBIPARTGGSTATEFREE;
-      vexxtax[vertnum].commgain      = vexxtax[vertnum].commgain0;
+      bgraphBipartGgSetFree (&vexxtax[vertnum]);
+      vexxtax[vertnum].commgain = vexxtax[vertnum].commgain0;
     }
-    gainTablFree (tablptr);                       /* Reset gain table                          */
+    bgraphBipartGgTablFree (&tabldat);            /* Reset gain table                          */
     permnum      = 0;                             /* No permutation built yet                  */
     compload0dlt = grafptr->s.velosum - grafptr->compload0avg; /* Reset bipartition parameters */
     commload     = grafptr->commloadextn0;
@@ -192,11 +230,13 @@ const BgraphBipartGgParam * const paraptr)        /*+ Method parameters +*/
     vexxptr = vexxtax + (grafptr->s.baseval + intRandVal (grafptr->s.vertnbr)); /* Randomly select first root vertex */
 
     do {                                          /* For all root vertices, till balance  */
+#ifdef SCOTCH_TABLE_GAIN
       vexxptr->gainlink.next =                    /* TRICK: allow deletion of root vertex */
       vexxptr->gainlink.prev = (GainLink *) vexxptr;
-#ifdef SCOTCH_DEBUG_GAIN2
+#ifdef SCOTCH_DEBUG_BGRAPH2
       vexxptr->gainlink.tabl = NULL;
-#endif /* SCOTCH_DEBUG_GAIN2 */
+#endif /* SCOTCH_DEBUG_BGRAPH2 */
+#endif /* SCOTCH_TABLE_GAIN    */
 
       do {                                        /* As long as vertices can be retrieved */
         const Gnum * restrict       edgeptr;      /* Pointer to current end vertex index  */
@@ -205,49 +245,56 @@ const BgraphBipartGgParam * const paraptr)        /*+ Method parameters +*/
         Gnum                        vertnum;      /* Number of current vertex             */
         Gnum                        veloval;      /* Load of selected vertex              */
 
-        gainTablDel (tablptr, (GainLink *) vexxptr); /* Remove vertex from the table */
-        vertnum = vexxptr - vexxtax;              /* Get number of selected vertex   */
+#ifndef SCOTCH_TABLE_GAIN
+        if (bgraphBipartGgIsTabl (vexxptr))
+#endif /* SCOTCH_TABLE_GAIN */
+        bgraphBipartGgTablDel (&tabldat, vexxptr); /* Remove vertex from table */
+
+        vertnum = vexxptr - vexxtax;              /* Get number of selected vertex */
         veloval = velobax[vertnum & velomsk];
 
         if (abs (compload0dlt - veloval) >= abs (compload0dlt)) { /* If swapping would cause imbalance */
-          permnum = grafptr->s.vertnbr;           /* Terminate swapping process                        */
+#ifndef SCOTCH_TABLE_GAIN
+          bgraphBipartGgNext (vexxptr) = BGRAPHBIPARTGGSTATELINK; /* Vertex belongs to frontier of part 0 */
+#endif /* SCOTCH_TABLE_GAIN */
+          permnum = grafptr->s.vertnbr;           /* Terminate swapping process */
           vexxptr = NULL;
           break;
         }
 
-        vexxptr->gainlink.next = BGRAPHBIPARTGGSTATEUSED; /* Mark it as swapped  */
+        bgraphBipartGgSetUsed (vexxptr);          /* Mark it as swapped          */
         compload0dlt -= veloval;                  /* Update partition parameters */
         commload     += vexxptr->commgain;
-        for (edgeptr = grafptr->s.edgetax + grafptr->s.verttax[vertnum], /* (Re-)link neighbors */
-             edgetnd = grafptr->s.edgetax + grafptr->s.vendtax[vertnum],
-             edloptr = edlobax + (grafptr->s.verttax[vertnum] & edlomsk);
+        for (edgeptr = edgetax + verttax[vertnum], /* (Re-)link neighbors */
+             edgetnd = edgetax + vendtax[vertnum],
+             edloptr = edlobax + (verttax[vertnum] & edlomsk);
              edgeptr < edgetnd; edgeptr ++, edloptr -= edlomsk) { /* TRICK: assume that ~0 is -1 */
-          BgraphBipartGgVertex *          vexxend; /* Pointer to end vertex of current edge      */
+          BgraphBipartGgVertex *  vexxend;        /* Pointer to end vertex of current edge       */
 
-          vexxend = vexxtax + *edgeptr;           /* Point to end vertex                                 */
-          if (vexxend->gainlink.next != BGRAPHBIPARTGGSTATEUSED) { /* If vertex needs to be updated      */
-            vexxend->commgain -= *edloptr * domdist2; /* Adjust gain value                               */
-            if (vexxend->gainlink.next >= BGRAPHBIPARTGGSTATELINK) /* If vertex is linked                */
-              gainTablDel (tablptr, (GainLink *) vexxend); /* Remove it from table                       */
-            gainTablAdd (tablptr, (GainLink *) vexxend, vexxend->commgain); /* (Re-)link vertex in table */
+          vexxend = vexxtax + *edgeptr;           /* Point to end vertex            */
+          if (! bgraphBipartGgIsUsed (vexxend)) { /* If vertex needs to be updated  */
+            vexxend->commgain -= *edloptr * domndist2; /* Adjust gain value         */
+            if (bgraphBipartGgIsTabl (vexxend))   /* If vertex is linked            */
+              bgraphBipartGgTablDel (&tabldat, vexxend); /* Remove it from table    */
+            bgraphBipartGgTablAdd (&tabldat, vexxend); /* (Re-)link vertex in table */
           }
         }
-      } while ((vexxptr = (BgraphBipartGgVertex *) gainTablFrst (tablptr)) != NULL);
+      } while ((vexxptr = (BgraphBipartGgVertex *) bgraphBipartGgTablFrst (&tabldat)) != NULL);
 
       if (permnum == 0) {                         /* If permutation has not been built yet  */
         if (permtab == NULL) {                    /* If permutation array not allocated yet */
           if ((permtab = (Gnum *) memAlloc (grafptr->s.vertnbr * sizeof (Gnum))) == NULL) {
-            errorPrint   ("bgraphBipartGg: out of memory (2)");
-            memFree      (vexxtax + grafptr->s.baseval);
-            gainTablExit (tablptr);
-            return       (1);
+            errorPrint ("bgraphBipartGg: out of memory (3)");
+            memFree    (vexxtax + grafptr->s.baseval);
+            bgraphBipartGgTablExit (&tabldat);
+            return (1);
           }
           intAscn (permtab, grafptr->s.vertnbr, grafptr->s.baseval); /* Initialize based permutation array */
         }
         intPerm (permtab, grafptr->s.vertnbr);    /* Build random permutation */
       }
       for ( ; permnum < grafptr->s.vertnbr; permnum ++) { /* Find next root vertex */
-        if (vexxtax[permtab[permnum]].gainlink.next == BGRAPHBIPARTGGSTATEFREE) {
+        if (bgraphBipartGgIsFree (&vexxtax[permtab[permnum]])) {
           vexxptr = vexxtax + permtab[permnum ++];
           break;
         }
@@ -264,7 +311,7 @@ const BgraphBipartGgParam * const paraptr)        /*+ Method parameters +*/
       grafptr->commload     = commload;
 
       for (vertnum = grafptr->s.baseval; vertnum < grafptr->s.vertnnd; vertnum ++) /* Copy bipartition state with flag 2 for tabled vertices */
-        grafptr->parttax[vertnum] = (vexxtax[vertnum].gainlink.next >= BGRAPHBIPARTGGSTATELINK) ? 2 : (GraphPart) ((intptr_t) vexxtax[vertnum].gainlink.next);
+        grafptr->parttax[vertnum] = (bgraphBipartGgIsTabl (&vexxtax[vertnum])) ? 2 : (GraphPart) ((intptr_t) bgraphBipartGgNext (&vexxtax[vertnum]));
     }
   }
 
@@ -281,11 +328,11 @@ const BgraphBipartGgParam * const paraptr)        /*+ Method parameters +*/
 
       grafptr->frontab[fronnum ++] = vertnum;     /* Then it belongs to the frontier */
       grafptr->parttax[vertnum]    = 0;           /* And it belongs to part 0        */
-      for (edgenum = grafptr->s.verttax[vertnum], frontmp = 1;
-           edgenum < grafptr->s.vendtax[vertnum]; edgenum ++) {
+      for (edgenum = verttax[vertnum], frontmp = 1;
+           edgenum < vendtax[vertnum]; edgenum ++) {
         Gnum                vertend;
 
-        vertend = grafptr->s.edgetax[edgenum];
+        vertend = edgetax[edgenum];
         if (grafptr->parttax[vertend] == 1) {     /* If vertex belongs to other part       */
           frontmp = 0;                            /* Then first frontier vertex was useful */
           if (flagtax[vertend] != 0) {            /* If vertex has not yet been flagged    */
@@ -308,8 +355,8 @@ const BgraphBipartGgParam * const paraptr)        /*+ Method parameters +*/
 
   if (permtab != NULL)                            /* Free work arrays */
     memFree (permtab);
-  memFree      (vexxtax + grafptr->s.baseval);
-  gainTablExit (tablptr);
+  memFree (vexxtax + grafptr->s.baseval);
+  bgraphBipartGgTablExit (&tabldat);
 
 #ifdef SCOTCH_DEBUG_BGRAPH2
   if (bgraphCheck (grafptr) != 0) {
