@@ -1,4 +1,4 @@
-/* Copyright 2004,2007-2010 ENSEIRB, INRIA & CNRS
+/* Copyright 2004,2007-2010,2012,2014 Universite de Bordeaux, INRIA & CNRS
 **
 ** This file is part of the Scotch software package for static mapping,
 ** graph partitioning and sparse matrix ordering.
@@ -51,6 +51,8 @@
 /**                                 to   : 03 apr 2008     **/
 /**                # Version 5.1  : from : 16 jun 2008     **/
 /**                                 to   : 15 aug 2010     **/
+/**                # Version 6.0  : from : 01 dec 2012     **/
+/**                                 to   : 12 nov 2014     **/
 /**                                                        **/
 /************************************************************/
 
@@ -67,11 +69,11 @@
 #define C_FILENBR                   2             /* Number of files in list                */
 #define C_FILEARGNBR                2             /* Number of files which can be arguments */
 
-#define C_filenamehedinp            C_fileTab[0].name /* Source graph input file name */
-#define C_filenamehedout            C_fileTab[1].name /* Statistics output file name  */
+#define C_filenamehedinp            C_fileTab[0].nameptr /* Source graph input file name */
+#define C_filenamehedout            C_fileTab[1].nameptr /* Statistics output file name  */
 
-#define C_filepntrhedinp            C_fileTab[0].pntr /* Source graph input file */
-#define C_filepntrhedout            C_fileTab[1].pntr /* Statistics output file  */
+#define C_filepntrhedinp            C_fileTab[0].fileptr /* Source graph input file */
+#define C_filepntrhedout            C_fileTab[1].fileptr /* Statistics output file  */
 
 #define EXPAND(s)                   EXPANDTWO(s)
 #define EXPANDTWO(s)                #s
@@ -101,8 +103,8 @@
 
 static int                  C_fileNum = 0;        /* Number of file in arg list */
 static File                 C_fileTab[C_FILENBR] = { /* The file array          */
-                              { "-", NULL, "r" },
-                              { "-", NULL, "w" } };
+                              { "r" },
+                              { "w" } };
 
 /******************************/
 /*                            */
@@ -148,12 +150,12 @@ char *                      argv[])
   }
 
   for (i = 0; i < C_FILENBR; i ++)                /* Set default stream pointers */
-    C_fileTab[i].pntr = (C_fileTab[i].mode[0] == 'r') ? stdin : stdout;
+    C_fileTab[i].fileptr = (C_fileTab[i].modeptr[0] == 'r') ? stdin : stdout;
   for (i = 1; i < argc; i ++) {                   /* Loop for all option codes */
     if ((argv[i][0] != '+') &&                    /* If found a file name      */
         ((argv[i][0] != '-') || (argv[i][1] == '\0'))) {
       if (C_fileNum < C_FILEARGNBR)               /* A file name has been given */
-        C_fileTab[C_fileNum ++].name = argv[i];
+        C_fileTab[C_fileNum ++].nameptr = argv[i];
       else {
         fprintf (stderr, "dummysizes: ERROR: main: too many file names given");
         exit    (1);
@@ -178,26 +180,25 @@ char *                      argv[])
   }
 
   for (i = 0; i < C_FILENBR; i ++) {              /* For all file names     */
-    if ((C_fileTab[i].name[0] != '-') ||          /* If not standard stream */
-        (C_fileTab[i].name[1] != '\0')) {
-      if ((C_fileTab[i].pntr = fopen (C_fileTab[i].name, C_fileTab[i].mode)) == NULL) { /* Open the file */
+    if ((C_fileTab[i].nameptr[0] != '-') ||       /* If not standard stream */
+        (C_fileTab[i].nameptr[1] != '\0')) {
+      if ((C_fileTab[i].fileptr = fopen (C_fileTab[i].nameptr, C_fileTab[i].modeptr)) == NULL) { /* Open the file */
           fprintf (stderr, "dummysizes: ERROR: main: cannot open file (%d)", i);
           exit    (1);
       }
     }
   }
 
-  substab[0][0] = "library.h ";
 #ifdef SCOTCH_PTSCOTCH
-  substab[0][1] = "scotch.h  ";
+  substab[0][0] = "library_pt.h";
+  substab[0][1] = "ptscotch.h  ";
+  substab[1][0] = "library_pt_f.h";
+  substab[1][1] = "ptscotchf.h   ";
 #else /* SCOTCH_PTSCOTCH */
-  substab[0][1] = "ptscotch.h";
-#endif /* SCOTCH_PTSCOTCH */
-  substab[1][0] = "libraryf.h ";
-#ifdef SCOTCH_PTSCOTCH
+  substab[0][0] = "library.h";
+  substab[0][1] = "scotch.h ";
+  substab[1][0] = "library_f.h";
   substab[1][1] = "scotchf.h  ";
-#else /* SCOTCH_PTSCOTCH */
-  substab[1][1] = "ptscotchf.h";
 #endif /* SCOTCH_PTSCOTCH */
   substab[2][0] = "DUMMYIDX";
   substab[2][1] = EXPAND (IDX);
@@ -207,19 +208,13 @@ char *                      argv[])
   substab[4][1] = EXPAND (INTVALMAX);
   substab[5][0] = "DUMMYNUMSTRING";
   substab[5][1] = "\"" GNUMSTRING "\"";
-  substab[6][0] = "DUMMYPTFLAG";
-#ifdef SCOTCH_PTSCOTCH
-  substab[6][1] = "PTSCOTCH";
-#else /* SCOTCH_PTSCOTCH */
-  substab[6][1] = "SEQSCOTCH";
-#endif /* SCOTCH_PTSCOTCH */
-  substab[7][0] = "DUMMYVERSION";
-  substab[7][1] = EXPAND (SCOTCH_VERSION);
-  substab[8][0] = "DUMMYRELEASE";
-  substab[8][1] = EXPAND (SCOTCH_RELEASE);
-  substab[9][0] = "DUMMYPATCHLEVEL";
-  substab[9][1] = EXPAND (SCOTCH_PATCHLEVEL);
-  subsnbr = 10;
+  substab[6][0] = "DUMMYVERSION";
+  substab[6][1] = EXPAND (SCOTCH_VERSION);
+  substab[7][0] = "DUMMYRELEASE";
+  substab[7][1] = EXPAND (SCOTCH_RELEASE);
+  substab[8][0] = "DUMMYPATCHLEVEL";
+  substab[8][1] = EXPAND (SCOTCH_PATCHLEVEL);
+  subsnbr = 9;
   subsFill (substab[subsnbr ++], "DUMMYSIZEARCH",          sizeof (Arch));
   subsFill (substab[subsnbr ++], "DUMMYSIZEGEOM",          sizeof (Geom));
   subsFill (substab[subsnbr ++], "DUMMYSIZEGRAPH",         sizeof (Graph));
