@@ -1,4 +1,4 @@
-/* Copyright 2007,2008 ENSEIRB, INRIA & CNRS
+/* Copyright 2007,2008,2012,2014 IPB, Universite de Bordeaux, INRIA & CNRS
 **
 ** This file is part of the Scotch software package for static mapping,
 ** graph partitioning and sparse matrix ordering.
@@ -41,6 +41,8 @@
 /**                                                        **/
 /**   DATES      : # Version 5.0  : from : 23 jun 2007     **/
 /**                                 to     03 apr 2008     **/
+/**                # Version 6.0  : from : 29 nov 2012     **/
+/**                                 to     29 oct 2014     **/
 /**                                                        **/
 /************************************************************/
 
@@ -54,7 +56,7 @@
 #include "common.h"
 #include "dgraph.h"
 #include "library_dgraph_stat.h"
-#include "scotch.h"
+#include "ptscotch.h"
 
 /*
 **  The static variables.
@@ -266,13 +268,22 @@ double *                    edlodltptr)
   }
   srclstadat.edlodlt = edlolocdlt;
 
+#if ((defined COMMON_MPI_VERSION) && (COMMON_MPI_VERSION <= 100))
   MPI_Address (&srclstadat.velomin, &srcdisptab[0]);
   MPI_Address (&srclstadat.velodlt, &srcdisptab[1]);
+#else /* ((defined COMMON_MPI_VERSION) && (COMMON_MPI_VERSION <= 100)) */
+  MPI_Get_address (&srclstadat.velomin, &srcdisptab[0]);
+  MPI_Get_address (&srclstadat.velodlt, &srcdisptab[1]);
+#endif /* ((defined COMMON_MPI_VERSION) && (COMMON_MPI_VERSION <= 100)) */
   srcdisptab[1] -= srcdisptab[0];
   srcdisptab[0] -= srcdisptab[0];
 
   o = 1;                                          /* Assume something will go wrong */
+#if ((defined COMMON_MPI_VERSION) && (COMMON_MPI_VERSION <= 100))
   if ((MPI_Type_struct (2, dgraphstatblentab, srcdisptab, dgraphstattypetab, &srctypedat) == MPI_SUCCESS) &&
+#else /* ((defined COMMON_MPI_VERSION) && (COMMON_MPI_VERSION <= 100)) */
+  if ((MPI_Type_create_struct (2, dgraphstatblentab, srcdisptab, dgraphstattypetab, &srctypedat) == MPI_SUCCESS) &&
+#endif /* ((defined COMMON_MPI_VERSION) && (COMMON_MPI_VERSION <= 100)) */
       (MPI_Type_commit (&srctypedat) == MPI_SUCCESS)) {
     if (MPI_Op_create ((MPI_User_function *) dgraphStatReduceAll, 0, &srcoperdat) == MPI_SUCCESS) {
       if (MPI_Allreduce (&srclstadat, &srcgstadat, 1, srctypedat, srcoperdat, srcgrafptr->proccomm) == MPI_SUCCESS)
