@@ -44,7 +44,7 @@
 /**                # Version 5.0  : from : 04 aug 2007     **/
 /**                                 to     04 aug 2007     **/
 /**                # Version 5.1  : from : 27 mar 2010     **/
-/**                                 to     29 mar 2010     **/
+/**                                 to     25 jul 2010     **/
 /**                                                        **/
 /************************************************************/
 
@@ -65,28 +65,6 @@
 /*                                    */
 /**************************************/
 
-FORTRAN (                                       \
-SCOTCHFSTRATMESHORDER, scotchfstratmeshorder, ( \
-SCOTCH_Strat * const        stratptr,           \
-const char * const          string,             \
-int * const                 revaptr,            \
-const int                   strnbr),            \
-(stratptr, string, revaptr, strnbr))
-{
-  char * restrict     strtab;                     /* Pointer to null-terminated string */
-
-  if ((strtab = (char *) memAlloc (strnbr + 1)) == NULL) { /* Allocate temporary space */
-    errorPrint ("SCOTCHFSTRATMESHORDER: out of memory (1)");
-    *revaptr = 1;
-  }
-  memCpy (strtab, string, strnbr);                /* Copy string contents */
-  strtab[strnbr] = '\0';                          /* Terminate string     */
-
-  *revaptr = SCOTCH_stratMeshOrder (stratptr, strtab); /* Call original routine */
-
-  memFree (strtab);                               /* Prevent compiler warnings */
-}
-
 /*
 **
 */
@@ -234,7 +212,7 @@ int * const                   revaptr),               \
 
 FORTRAN (                                           \
 SCOTCHFMESHORDERCOMPUTE, scotchfmeshordercompute, ( \
-const SCOTCH_Mesh * const   meshptr,                \
+SCOTCH_Mesh * const         meshptr,                \
 SCOTCH_Ordering * const     ordeptr,                \
 SCOTCH_Strat * const        stratptr,               \
 int * const                 revaptr),               \
@@ -249,7 +227,7 @@ int * const                 revaptr),               \
 
 FORTRAN (                                                   \
 SCOTCHFMESHORDERCOMPUTELIST, scotchfmeshordercomputelist, ( \
-const SCOTCH_Mesh * const   meshptr,                        \
+SCOTCH_Mesh * const         meshptr,                        \
 SCOTCH_Ordering * const     ordeptr,                        \
 const SCOTCH_Num *          listptr,                        \
 const SCOTCH_Num * const    listtab,                        \
@@ -266,7 +244,7 @@ int * const                 revaptr),                       \
 
 FORTRAN (                                       \
 SCOTCHFMESHORDER, scotchfmeshorder, (           \
-const SCOTCH_Mesh * const   meshptr,            \
+SCOTCH_Mesh * const         meshptr,            \
 SCOTCH_Strat * const        stratptr,           \
 SCOTCH_Num * const          permtab,            \
 SCOTCH_Num * const          peritab,            \
@@ -286,7 +264,7 @@ int * const                 revaptr),           \
 
 FORTRAN (                                       \
 SCOTCHFMESHORDERLIST, scotchfmeshorderlist, (   \
-const SCOTCH_Mesh * const   meshptr,            \
+SCOTCH_Mesh * const         meshptr,            \
 const SCOTCH_Num * const    listptr,            \
 const SCOTCH_Num * const    listtab,            \
 SCOTCH_Strat * const        stratptr,           \
@@ -315,3 +293,44 @@ int * const                 revaptr),           \
 {
   *revaptr = SCOTCH_meshOrderCheck (meshptr, ordeptr);
 }
+
+/*
+**
+*/
+
+FORTRAN (                                       \
+SCOTCHFSTRATMESHORDER, scotchfstratmeshorder, ( \
+SCOTCH_Strat * const        stratptr,           \
+const char * const          string,             \
+int * const                 revaptr,            \
+const int                   strnbr),            \
+(stratptr, string, revaptr, strnbr))
+{
+  char * restrict     strtab;                     /* Pointer to null-terminated string */
+
+  if ((strtab = (char *) memAlloc (strnbr + 1)) == NULL) { /* Allocate temporary space */
+    errorPrint ("SCOTCHFSTRATMESHORDER: out of memory (1)");
+    *revaptr = 1;
+  }
+  memCpy (strtab, string, strnbr);                /* Copy string contents */
+  strtab[strnbr] = '\0';                          /* Terminate string     */
+
+  *revaptr = SCOTCH_stratMeshOrder (stratptr, strtab); /* Call original routine */
+
+  memFree (strtab);                               /* Prevent compiler warnings */
+}
+
+/*
+**
+*/
+
+FORTRAN (                                                 \
+SCOTCHFSTRATMESHORDERBUILD, scotchfstratmeshorderbuild, ( \
+SCOTCH_Strat * const        stratptr,                     \
+const SCOTCH_Num * const    flagval,                      \
+const double * const        balrat,                       \
+int * const                 revaptr),                     \
+(stratptr, flagval, balrat, revaptr))
+{
+  *revaptr = SCOTCH_stratMeshOrderBuild (stratptr, *flagval, *balrat);
+}
