@@ -1,4 +1,4 @@
-/* Copyright 2007,2008 ENSEIRB, INRIA & CNRS
+/* Copyright 2007,2008,2010 ENSEIRB, INRIA & CNRS
 **
 ** This file is part of the Scotch software package for static mapping,
 ** graph partitioning and sparse matrix ordering.
@@ -43,8 +43,8 @@
 /**                computing, and projecting back the      **/
 /**                best result obtained.                   **/
 /**                                                        **/
-/**   DATES      : # Version 5.0  : from : 15 feb 2006     **/
-/**                                 to     01 mar 2008     **/
+/**   DATES      : # Version 5.1  : from : 15 feb 2006     **/
+/**                                 to     30 jul 2010     **/
 /**                                                        **/
 /************************************************************/
 
@@ -53,10 +53,10 @@
 */
 
 #define VDGRAPH_SEPARATE_SQ
-#define VDGRAPH_H
 
 #include "module.h"
 #include "common.h"
+#include "comm.h"
 #include "parser.h"
 #include "graph.h"
 #include "vgraph.h"
@@ -131,11 +131,13 @@ const VdgraphSeparateSqParam * const  paraptr)    /*+ Method parameters +*/
   MPI_Datatype      besttypedat;                  /* Data type for finding best separator              */
   MPI_Op            bestoperdat;                  /* Handle of MPI operator for finding best separator */
   int               bestprocnum;                  /* Rank of process holding best partition            */
+  Gnum * restrict   vnumloctax;
   Gnum              vertlocnum;
   Gnum              complocsize1;
   Gnum              complocload1;
   Gnum              complocload2;
   Gnum              fronlocnbr;
+  int               o;
 
   if ((MPI_Type_contiguous (4, GNUM_MPI, &besttypedat)                                != MPI_SUCCESS) ||
       (MPI_Type_commit (&besttypedat)                                                 != MPI_SUCCESS) ||
@@ -149,7 +151,11 @@ const VdgraphSeparateSqParam * const  paraptr)    /*+ Method parameters +*/
   reduloctab[2] = dgrfptr->s.proclocnum;
   reduloctab[3] = 0;                              /* Assume sequential separation went fine */
 
-  if (vdgraphGatherAll (dgrfptr, &cgrfdat) != 0) {
+  vnumloctax = dgrfptr->s.vnumloctax;             /* No need for vertex number array when centralizing graph */
+  dgrfptr->s.vnumloctax = NULL;
+  o = vdgraphGatherAll (dgrfptr, &cgrfdat);
+  dgrfptr->s.vnumloctax = vnumloctax;             /* Restore vertex number array */
+  if (o != 0) {
     errorPrint ("vdgraphSeparateSq: cannot build centralized graph");
     return     (1);
   }
@@ -213,7 +219,7 @@ const VdgraphSeparateSqParam * const  paraptr)    /*+ Method parameters +*/
   dgrfptr->compglbsize[1] = reduloctab[5];
   dgrfptr->compglbsize[2] = reduloctab[6];
 
-  if (MPI_Scatterv (cgrfdat.parttax, dgrfptr->s.proccnttab, dgrfptr->s.procdsptab, GRAPHPART_MPI, /* No base for sending as procdsptab holds based values */
+  if (commScatterv (cgrfdat.parttax, dgrfptr->s.proccnttab, dgrfptr->s.procdsptab, GRAPHPART_MPI, /* No base for sending as procdsptab holds based values */
                     dgrfptr->partgsttax + dgrfptr->s.baseval, dgrfptr->s.vertlocnbr, GRAPHPART_MPI,
                     bestprocnum, dgrfptr->s.proccomm) != MPI_SUCCESS) {
     errorPrint ("vdgraphSeparateSq: communication error (6)");
