@@ -1,4 +1,4 @@
-/* Copyright 2004,2007,2008 ENSEIRB, INRIA & CNRS
+/* Copyright 2004,2007,2008,2014 IPB, Universite de Bordeaux, INRIA & CNRS
 **
 ** This file is part of the Scotch software package for static mapping,
 ** graph partitioning and sparse matrix ordering.
@@ -47,6 +47,8 @@
 /**                                 to   : 01 jun 1997     **/
 /**                # Version 3.3  : from : 02 oct 1998     **/
 /**                                 to   : 02 oct 1998     **/
+/**                # Version 6.0  : from : 12 nov 2014     **/
+/**                                 to   : 12 nov 2014     **/
 /**                                                        **/
 /************************************************************/
 
@@ -59,8 +61,8 @@
 #define C_FILENBR                   2             /* Number of files in list                */
 #define C_FILEARGNBR                2             /* Number of files which can be arguments */
 
-#define C_filenametgtinp            C_fileTab[0].name /* Target architecture input file name  */
-#define C_filenametgtout            C_fileTab[1].name /* Target architecture output file name */
+#define C_filenametgtinp            fileBlockName (C_fileTab, 0) /* Target architecture input file name  */
+#define C_filenametgtout            fileBlockName (C_fileTab, 1) /* Target architecture output file name */
 
-#define C_filepntrtgtinp            C_fileTab[0].pntr /* Target architecture input file  */
-#define C_filepntrtgtout            C_fileTab[1].pntr /* Target architecture output file */
+#define C_filepntrtgtinp            fileBlockFile (C_fileTab, 0) /* Target architecture input file  */
+#define C_filepntrtgtout            fileBlockFile (C_fileTab, 1) /* Target architecture output file */
