@@ -1,4 +1,4 @@
-/* Copyright 2004,2007,2008,2011 ENSEIRB, INRIA & CNRS
+/* Copyright 2004,2007,2008,2011,2014 IPB, Universite de Bordeaux, INRIA & CNRS
 **
 ** This file is part of the Scotch software package for static mapping,
 ** graph partitioning and sparse matrix ordering.
@@ -49,6 +49,8 @@
 /**                                 to   : 15 may 1999     **/
 /**                # Version 5.1  : from : 17 jul 2011     **/
 /**                                 to   : 17 jul 2011     **/
+/**                # Version 6.0  : from : 12 nov 2014     **/
+/**                                 to   : 12 nov 2014     **/
 /**                                                        **/
 /************************************************************/
 
@@ -61,13 +63,13 @@
 #define C_FILENBR                 3              /* Number of files in list                */
 #define C_FILEARGNBR              2              /* Number of files which can be arguments */
 
-#define C_filenamegrfinp          C_fileTab[0].name /* Source graph input file name  */
-#define C_filenametgtout          C_fileTab[1].name /* Architecture output file name */
-#define C_filenamevrtinp          C_fileTab[2].name /* Vertex list input file name   */
+#define C_filenamegrfinp          fileBlockName (C_fileTab, 0) /* Source graph input file name  */
+#define C_filenametgtout          fileBlockName (C_fileTab, 1) /* Architecture output file name */
+#define C_filenamevrtinp          fileBlockName (C_fileTab, 2) /* Vertex list input file name   */
 
-#define C_filepntrgrfinp          C_fileTab[0].pntr /* Source graph input file  */
-#define C_filepntrtgtout          C_fileTab[1].pntr /* Architecture output file */
-#define C_filepntrvrtinp          C_fileTab[2].pntr /* Vertex list input file   */
+#define C_filepntrgrfinp          fileBlockFile (C_fileTab, 0) /* Source graph input file  */
+#define C_filepntrtgtout          fileBlockFile (C_fileTab, 1) /* Architecture output file */
+#define C_filepntrvrtinp          fileBlockFile (C_fileTab, 2) /* Vertex list input file   */
 
 /*+ Process flags. +*/
 
