@@ -1,4 +1,4 @@
-/* Copyright 2004,2007,2008,2010,2011 ENSEIRB, INRIA & CNRS
+/* Copyright 2004,2007,2008,2010,2011,2014 IPB, Universite de Bordeaux, INRIA & CNRS
 **
 ** This file is part of the Scotch software package for static mapping,
 ** graph partitioning and sparse matrix ordering.
@@ -34,6 +34,7 @@
 /**   NAME       : gmap.h                                  **/
 /**                                                        **/
 /**   AUTHOR     : Francois PELLEGRINI                     **/
+/**                Sebastien FOURESTIER (v6.0)             **/
 /**                                                        **/
 /**   FUNCTION   : Part of a graph static mapper.          **/
 /**                These lines are the data declaration    **/
@@ -61,6 +62,8 @@
 /**                                 to   : 18 jun 2008     **/
 /**                # Version 5.1  : from : 28 aug 2010     **/
 /**                                 to   : 18 jul 2011     **/
+/**                # Version 6.0  : from : 29 may 2010     **/
+/**                                 to   : 12 nov 2014     **/
 /**                                                        **/
 /************************************************************/
 
@@ -70,24 +73,53 @@
 
 /*+ File name aliases. +*/
 
-#define C_FILENBR                   4             /* Number of files in list */
+#define C_FILENBR                   7             /* Number of files in list */
 
-#define C_filenamesrcinp            C_fileTab[0].name /* Source graph input file name        */
-#define C_filenametgtinp            C_fileTab[1].name /* Target architecture input file name */
-#define C_filenamemapout            C_fileTab[2].name /* Mapping result output file name     */
-#define C_filenamelogout            C_fileTab[3].name /* Log file name                       */
+#define C_filenamesrcinp            fileBlockName (C_fileTab, 0) /* Source graph input file name        */
+#define C_filenametgtinp            fileBlockName (C_fileTab, 1) /* Target architecture input file name */
+#define C_filenamemapout            fileBlockName (C_fileTab, 2) /* Mapping result output file name     */
+#define C_filenamelogout            fileBlockName (C_fileTab, 3) /* Log file name                       */
+#define C_filenamevfxinp            fileBlockName (C_fileTab, 4) /* Fixed vertex file                   */
+#define C_filenamemaoinp            fileBlockName (C_fileTab, 5) /* Old mapping file                    */
+#define C_filenamevmlinp            fileBlockName (C_fileTab, 6) /* Vertex migration load file          */
 
-#define C_filepntrsrcinp            C_fileTab[0].pntr /* Source graph input file        */
-#define C_filepntrtgtinp            C_fileTab[1].pntr /* Target architecture input file */
-#define C_filepntrmapout            C_fileTab[2].pntr /* Mapping result output file     */
-#define C_filepntrlogout            C_fileTab[3].pntr /* Log file                       */
+#define C_filepntrsrcinp            fileBlockFile (C_fileTab, 0) /* Source graph input file        */
+#define C_filepntrtgtinp            fileBlockFile (C_fileTab, 1) /* Target architecture input file */
+#define C_filepntrmapout            fileBlockFile (C_fileTab, 2) /* Mapping result output file     */
+#define C_filepntrlogout            fileBlockFile (C_fileTab, 3) /* Log file                       */
+#define C_filepntrvfxinp            fileBlockFile (C_fileTab, 4) /* Fixed vertex file                   */
+#define C_filepntrmaoinp            fileBlockFile (C_fileTab, 5) /* Old mapping file                    */
+#define C_filepntrvmlinp            fileBlockFile (C_fileTab, 6) /* Vertex migration load file          */
 
 /*+ Process flags. +*/
 
-#define C_FLAGNONE                  0x0000        /* No flags            */
-#define C_FLAGPART                  0x0001        /* Partitioning        */
-#define C_FLAGVERBSTR               0x0002        /* Verbose flags       */
-#define C_FLAGVERBTIM               0x0004
-#define C_FLAGVERBMAP               0x0008
-#define C_FLAGKBALVAL               0x0010        /* Imbalance tolerance */
-#define C_FLAGCLUSTER               0x0020        /* Clustering          */
+#define C_FLAGNONE                  0x0000        /* No flags                   */
+#define C_FLAGPART                  0x0001        /* Partitioning               */
+#define C_FLAGPARTOVL               0x0002        /* Partitioning with overlap  */
+#define C_FLAGVERBSTR               0x0004        /* Verbose flags              */
+#define C_FLAGVERBTIM               0x0008
+#define C_FLAGVERBMAP               0x0010
+#define C_FLAGKBALVAL               0x0020        /* Imbalance tolerance        */
+#define C_FLAGCLUSTER               0x0040        /* Clustering                 */
+#define C_FLAGFIXED                 0x0080        /* Fixed vertices input file  */
+#define C_FLAGRMAPOLD               0x0100        /* Old mapping file           */
+#define C_FLAGRMAPRAT               0x0200        /* Edge migration ratio       */
+#define C_FLAGRMAPCST               0x0400        /* Vertex migration cost file */
+
+/*
+**  The type and structure definitions.
+*/
+
+/*+ This structure stores part lists. +*/
+
+typedef struct C_PartList_ {
+  SCOTCH_Num                vertnum;              /*+ Number of vertex of which part is neighbor +*/
+  SCOTCH_Num                nextidx;              /*+ Pointer to index of next recorded neighbor +*/
+} C_PartList;
+
+/*
+**  The function prototypes.
+*/
+
+void                        C_partSave          (SCOTCH_Graph * restrict const, SCOTCH_Num * restrict const, FILE * const);
+void                        C_partViewOvl       (SCOTCH_Graph * restrict const, SCOTCH_Num * restrict const, FILE * const);
